{* $data parameter is required *}
<div id="{$data->containerID}-container" class="google-map-container"></div>

<script>
(function($, $window, $document, globals){
"use strict";
function initialize(data, options)
{
	// default map settings that you can override
	var mapData = {
		mapName: "",
		containerID: "",
		center: new google.maps.LatLng(0, 0),
		markers: [],
		buildPath: false,
		strokeColor: '#FF0000',
		zoom: 10,
		flightPlanCoordinates: [],
		showAllMarkers: true,
		bounds: new google.maps.LatLngBounds(),
		infoWindow: null,
	};
	mapData = $.extend( mapData, data );

	var mapContainer = $("#" + mapData.containerID + "-container").get(0);

	var mapOptions = {
		zoom: options.zoom,
	    streetViewControl: true,
	    streetViewControlOptions: {
	    	position: google.maps.ControlPosition.RIGHT_TOP
	    },
		zoomControl: true,
		zoomControlOptions: {
	        position: google.maps.ControlPosition.RIGHT_TOP
	    },
		mapTypeId: google.maps.MapTypeId[options.type],

		draggable: options.draggable,
		scrollwheel: options.scrollwheel,
		panControl: false,
	};

	// create global variable (if doesn't exist) that stores references to all created maps
	// make sure you are using unique name - there might be another map already stored
	var map = new google.maps.Map(mapContainer,	mapOptions);

	if (typeof globals.globalMaps === "undefined") {
		globals.globalMaps = {};
	}
	var mapName = mapData.mapName;
	globals.globalMaps[mapName] = {
		map: map,
		bounds: mapData.bounds,
	};

	// place markers on the map
	initMarkers(map, mapData);
	autoFit(map, mapData);
}


function placeMarker(map, marker, mapData)
{
	if (marker.icon) {
		var icon = {
			url: marker.icon,
			anchor: marker.align == 'center' ? new google.maps.Point(marker.w/2, marker.h/2) : new google.maps.Point(marker.w/2, marker.h),
		};
	} else {
		var icon = "";
	}

	var marker = new google.maps.Marker({
		position:  new google.maps.LatLng(marker.lat, marker.lng),
		map: map,
		icon: icon,
		title: marker.title,
		context: marker.context,
	});
	google.maps.event.addListener(marker, 'click', function(event) {
		if (mapData.infoWindow) {
			mapData.infoWindow.close();
		}
		mapData.infoWindow = openInfoWindow(map, marker)
	});

	return marker;
}


function openInfoWindow(map, marker)
{
	if (marker.title == "" && marker.context == "") {
		return;
	}
	var content = '<div class="infowindow-content"><h3>' + marker.title + '</h3><p>' + marker.context + '</p></div>';
	var infoWindow = new google.maps.InfoWindow({
		content: content,
		// maxWidth: 130,
	});
	infoWindow.open(map, marker);
	return infoWindow;
}


function buildPath(map, mapData)
{
	var flightPath = new google.maps.Polyline({
		path: mapData.flightPlanCoordinates,
		geodesic: true,
		strokeColor: mapData.strokeColor,
		strokeOpacity: 1.0,
		strokeWeight: 2
	});
	flightPath.setMap(map);
}


function autoFit(map, mapData)
{
	map.fitBounds(mapData.bounds);
    map.panToBounds(mapData.bounds);
}


function initMarkers(map, mapData)
{
	for (var i in mapData.markers) {
		var marker = mapData.markers[i];
		var location = new google.maps.LatLng(marker.lat, marker.lng);

		mapData.bounds.extend(location);

		if (mapData.showAllMarkers === true && (marker.title != "" || marker.context != "")) {
			var newMarker = placeMarker(map, marker, mapData);
		} else if(i == 0 || i == mapData.markers.length - 1) {
			var newMarker = placeMarker(map, marker, mapData);
		}
		// if (mapData.buildPath) {
		// 	mapData.flightPlanCoordinates.push(location);
		// 	buildPath(map, mapData);
		// }
	}
}





$window.load(function(){
	google.maps.event.addDomListener(window, 'load', initialize( {$data}, {$options} ));
});

})(jQuery, jQuery(window), jQuery(document), this);
</script>